summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorelliott_c <ocielliottc@users.noreply.github.com>2004-01-28 14:58:13 +0000
committerelliott_c <ocielliottc@users.noreply.github.com>2004-01-28 14:58:13 +0000
commite776df9378d5309c1b1f217f5d589095291f6c10 (patch)
tree4d2cefbbfb4263516c4b8062105234626f5ae1ff
parent50281911c9c0f3390dde23c80623c17febb4a1f2 (diff)
downloadATCD-e776df9378d5309c1b1f217f5d589095291f6c10.tar.gz
ChangeLogTag: Wed Jan 28 08:54:29 2004 Chad Elliott <elliott_c@ociweb.com>
-rw-r--r--ChangeLog9
-rw-r--r--bin/MakeProjectCreator/modules/GNUACEProjectCreator.pm2
-rw-r--r--bin/MakeProjectCreator/modules/GNUACEWorkspaceCreator.pm6
3 files changed, 13 insertions, 4 deletions
diff --git a/ChangeLog b/ChangeLog
index f7376838618..b7a95c0d922 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,12 @@
+Wed Jan 28 08:54:29 2004 Chad Elliott <elliott_c@ociweb.com>
+
+ * bin/MakeProjectCreator/modules/GNUACEProjectCreator.pm:
+ * bin/MakeProjectCreator/modules/GNUACEWorkspaceCreator.pm:
+
+ Changed the output name from Makefile to GNUmakefile in accordance
+ with [BUGID 1726]. GNU Make will look for GNUmakefile before it
+ looks for Makefile.
+
Wed Jan 28 08:20:59 2004 Chad Elliott <elliott_c@ociweb.com>
* bin/MakeProjectCreator/README:
diff --git a/bin/MakeProjectCreator/modules/GNUACEProjectCreator.pm b/bin/MakeProjectCreator/modules/GNUACEProjectCreator.pm
index ec50b22d8ef..754bfb5525f 100644
--- a/bin/MakeProjectCreator/modules/GNUACEProjectCreator.pm
+++ b/bin/MakeProjectCreator/modules/GNUACEProjectCreator.pm
@@ -83,7 +83,7 @@ sub project_file_name {
$name = $self->project_name();
}
- return $self->get_modified_project_file_name('Makefile' .
+ return $self->get_modified_project_file_name('GNUmakefile' .
($name eq '' ? '' : ".$name"),
'');
}
diff --git a/bin/MakeProjectCreator/modules/GNUACEWorkspaceCreator.pm b/bin/MakeProjectCreator/modules/GNUACEWorkspaceCreator.pm
index e1f70c29510..9bbfbf743ea 100644
--- a/bin/MakeProjectCreator/modules/GNUACEWorkspaceCreator.pm
+++ b/bin/MakeProjectCreator/modules/GNUACEWorkspaceCreator.pm
@@ -1,7 +1,7 @@
package GNUACEWorkspaceCreator;
# ************************************************************
# Description : A GNU Workspace (Makefile) creator for ACE
# Author : Chad Elliott
# Create Date : 5/13/2002
# ************************************************************
@@ -40,7 +40,7 @@ sub generate_implicit_project_dependencies {
sub workspace_file_name {
my($self) = shift;
- return $self->get_modified_workspace_name('Makefile', '');
+ return $self->get_modified_workspace_name('GNUmakefile', '');
}
@@ -58,7 +58,7 @@ sub pre_workspace {
print $fh "#----------------------------------------------------------------------------$crlf" .
"# GNU ACE Workspace$crlf" .
"#$crlf" .
- "# \@file Makefile$crlf" .
+ "# \@file GNUmakefile$crlf" .
"#$crlf" .
"# \$Id\$$crlf" .
"#$crlf" .
@@ -1,7 +1,7 @@
package GNUACEWorkspaceCreator;
# ************************************************************
-# Description : A GNU Workspace (Makefile) creator for ACE
+# Description : A GNU Workspace (GNUmakefile) creator for ACE
# Author : Chad Elliott
# Create Date : 5/13/2002